==> v1.36.1.tar.gz: netdata/docs/Demo-Sites.md <==
<!--
title: "Demo sites"
date: 2020-03-26
custom_edit_url: https://github.com/netdata/netdata/edit/master/docs/Demo-Sites.md
-->

# Demo sites

You can also view live demos of Netdata at **[https://www.netdata.cloud](https://www.netdata.cloud/#live-demo)**.

| Location            | Netdata demo URL                                                                                                                              | 60 mins reqs                                                                                                                                                                                                                                                 | VM donated by                                      |
| :------------------ | :-------------------------------------------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| :------------------------------------------------- |
| London (UK)         | **[london3.my-netdata.io](https://london3.my-netdata.io)**<br/>(this is the global Netdata **registry** and has **named** and **mysql** charts) | [![Requests Per Second](https://london3.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://london3.my-netdata.io)             | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Atlanta (USA)       | **[cdn77.my-netdata.io](https://cdn77.my-netdata.io)**<br/>(with **named** and **mysql** charts)                                              | [![Requests Per Second](https://cdn77.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://cdn77.my-netdata.io)               | [CDN77.com](https://www.cdn77.com/)                |
| Bangalore (India)   | **[bangalore.my-netdata.io](https://bangalore.my-netdata.io)**                                                                                | [![Requests Per Second](https://bangalore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://bangalore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Frankfurt (Germany) | **[frankfurt.my-netdata.io](https://frankfurt.my-netdata.io)**                                                                                | [![Requests Per Second](https://frankfurt.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://frankfurt.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| New York (USA)      | **[newyork.my-netdata.io](https://newyork.my-netdata.io)**                                                                                    | [![Requests Per Second](https://newyork.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://newyork.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| San Francisco (USA) | **[sanfrancisco.my-netdata.io](https://sanfrancisco.my-netdata.io)**                                                                          | [![Requests Per Second](https://sanfrancisco.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://sanfrancisco.my-netdata.io) | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Singapore           | **[singapore.my-netdata.io](https://singapore.my-netdata.io)**                                                                                | [![Requests Per Second](https://singapore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://singapore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Toronto (Canada)    | **[toronto.my-netdata.io](https://toronto.my-netdata.io)**                                                                                    | [![Requests Per Second](https://toronto.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://toronto.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |

Netdata dashboards are mobile- and touch-friendly.

==> v1.37.0.tar.gz: netdata/docs/Demo-Sites.md <==
<!--
title: "Demo sites"
date: 2020-03-26
custom_edit_url: https://github.com/netdata/netdata/edit/master/docs/Demo-Sites.md
-->

# Demo sites

You can also view live demos of Netdata at **https://app.netdata.cloud/spaces/netdata-demo**

| Location            | Netdata demo URL                                                                                                                              | 60 mins reqs                                                                                                                                                                                                                                                 | VM donated by                                      |
| :------------------ | :-------------------------------------------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| :------------------------------------------------- |
| London (UK)         | **[london3.my-netdata.io](https://london3.my-netdata.io)**<br/>(this is the global Netdata **registry** and has **named** and **mysql** charts) | [![Requests Per Second](https://london3.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://london3.my-netdata.io)             | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Atlanta (USA)       | **[cdn77.my-netdata.io](https://cdn77.my-netdata.io)**<br/>(with **named** and **mysql** charts)                                              | [![Requests Per Second](https://cdn77.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://cdn77.my-netdata.io)               | [CDN77.com](https://www.cdn77.com/)                |
| Bangalore (India)   | **[bangalore.my-netdata.io](https://bangalore.my-netdata.io)**                                                                                | [![Requests Per Second](https://bangalore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://bangalore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Frankfurt (Germany) | **[frankfurt.my-netdata.io](https://frankfurt.my-netdata.io)**                                                                                | [![Requests Per Second](https://frankfurt.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://frankfurt.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| New York (USA)      | **[newyork.my-netdata.io](https://newyork.my-netdata.io)**                                                                                    | [![Requests Per Second](https://newyork.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://newyork.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| San Francisco (USA) | **[sanfrancisco.my-netdata.io](https://sanfrancisco.my-netdata.io)**                                                                          | [![Requests Per Second](https://sanfrancisco.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://sanfrancisco.my-netdata.io) | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Singapore           | **[singapore.my-netdata.io](https://singapore.my-netdata.io)**                                                                                | [![Requests Per Second](https://singapore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://singapore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Toronto (Canada)    | **[toronto.my-netdata.io](https://toronto.my-netdata.io)**                                                                                    | [![Requests Per Second](https://toronto.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://toronto.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |

Netdata dashboards are mobile- and touch-friendly.
